@@ -40,16 +40,15 @@ class Client(object):
         policy = PutPolicy()
         policy.set_conf('scope', '%s:%s' % (bucket,key))
         policy.dump_policy(self.cfg)
-        print(policy.putpolicy)
         token = self.auth.uploadtoken(policy.putpolicy)
-        return self.simpleupload.upload(path,token)
+        return self.simpleupload.upload(path,token ,key)
 
     def stream_upload(self, stream, bucket, key):
         policy = PutPolicy()
         policy.set_conf('scope', '%s:%s' % (bucket,key))
         policy.dump_policy(self.cfg)
         token = self.auth.uploadtoken(policy.putpolicy)
-        return self.streamupload.upload(stream,token)
+        return self.streamupload.upload(stream,token ,key)
 
     def multipart_upload(self,path,bucket, key,tmp_upload_id=None):
         policy = PutPolicy()
