@@ -2,6 +2,8 @@
 ## -*- coding: utf-8 -*-
 
 import os
+from urllib.request import quote
+
 import requests
 from requests_toolbelt import MultipartEncoder
 from wcs.commons.http import _post
@@ -29,10 +31,10 @@ class SimpleUpload(object):
         global _session
         _session = session
 
-    def _gernerate_tool(self, f, token):
+    def _gernerate_tool(self, f, token ,key):
         fileds = {"token": token}
         url = "{0}/{1}/{2}".format(self.url, "file", "upload")
-        fileds['file'] = ('filename', f, 'text/plain')
+        fileds['file'] = (quote(key), f, 'text/plain')
         encoder = MultipartEncoder(fileds)
         headers = {"Content-Type": encoder.content_type}
         headers['Expect'] = '100-continue'
@@ -62,6 +64,9 @@ class SimpleUpload(object):
                     r = _session.post(url=url, headers=headers, data=encoder, verify=False, allow_redirects=False)
                 else:
                     r = _session.post(url=url, headers=headers, data=encoder, verify=False)
+        except requests.ConnectionError as conn_error:
+            debug('Url connection abnormal,please check url!')
+            return -1,conn_error
         except Exception as e:
             f.close()
             debug('Request url:' + url)
@@ -80,10 +85,10 @@ class SimpleUpload(object):
         except:
             return r.status_code, r.text
 
-    def upload(self, filepath, token):
+    def upload(self, filepath, token ,key='filename'):
         if os.path.exists(filepath) and os.path.isfile(filepath):
             f = self._gernerate_content(filepath)
-            url, encoder, headers = self._gernerate_tool(f, token)
+            url, encoder, headers = self._gernerate_tool(f, token ,key)
             return self._upload(url, encoder, headers, f)
         else:
             error('Sorry ! Please input a existing file')
